
#ifndef KHEALTHCERTIFICATE_EXPORT_H
#define KHEALTHCERTIFICATE_EXPORT_H

#ifdef KHEALTHCERTIFICATE_STATIC_DEFINE
#  define KHEALTHCERTIFICATE_EXPORT
#  define KHEALTHCERTIFICATE_NO_EXPORT
#else
#  ifndef KHEALTHCERTIFICATE_EXPORT
#    ifdef KHealthCertificate_EXPORTS
        /* We are building this library */
#      define KHEALTHCERTIFICATE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KHEALTHCERTIFICATE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KHEALTHCERTIFICATE_NO_EXPORT
#    define KHEALTHCERTIFICATE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KHEALTHCERTIFICATE_DEPRECATED
#  define KHEALTHCERTIFICATE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KHEALTHCERTIFICATE_DEPRECATED_EXPORT
#  define KHEALTHCERTIFICATE_DEPRECATED_EXPORT KHEALTHCERTIFICATE_EXPORT KHEALTHCERTIFICATE_DEPRECATED
#endif

#ifndef KHEALTHCERTIFICATE_DEPRECATED_NO_EXPORT
#  define KHEALTHCERTIFICATE_DEPRECATED_NO_EXPORT KHEALTHCERTIFICATE_NO_EXPORT KHEALTHCERTIFICATE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KHEALTHCERTIFICATE_NO_DEPRECATED
#    define KHEALTHCERTIFICATE_NO_DEPRECATED
#  endif
#endif

#endif /* KHEALTHCERTIFICATE_EXPORT_H */
