// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KHEALTHCERTIFICATE_VERSION_H
#define KHEALTHCERTIFICATE_VERSION_H

#define KHEALTHCERTIFICATE_VERSION_STRING "26.04.2"
#define KHEALTHCERTIFICATE_VERSION_MAJOR 26
#define KHEALTHCERTIFICATE_VERSION_MINOR 4
#define KHEALTHCERTIFICATE_VERSION_PATCH 2
#define KHEALTHCERTIFICATE_VERSION ((26<<16)|(4<<8)|(2))

#endif
